@@ -1,3 +1,5 @@
+message("*** DevEvalFileProduct ...")
+
 # Return the DevEvalProduct object by default
 R.devices::devOptions("*", field="*")
 
@@ -18,3 +20,5 @@ library("R.devices")
 # An empty file product
 na <- DevEvalFileProduct()
 print(na)
+
+message("*** DevEvalFileProduct ... DONE")
