@@ -1,10 +1,15 @@
+message("*** devEval() ...")
+
 library("R.devices")
 library("R.utils")
 graphics.off()
 
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Various types of single and multiple device outputs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** devEval() - single and multiple device outputs ...")
+
 types <- list(
   character(0L),
   "png",
@@ -28,10 +33,14 @@ for (type in types) {
 print(devList())
 stopifnot(length(devList()) == 0L)
 
+message("*** devEval() - single and multiple device outputs ... DONE")
+
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # With 'initially' and 'finally' expression
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** devEval() - initally and finally ...")
+
 devList0 <- devList()
 devEval(c("png", "jpg"), name="count", {
   plot(1:10)
@@ -51,10 +60,14 @@ stopifnot(all.equal(devList(), devList0))
 print(devList())
 stopifnot(length(devList()) == 0L)
 
+message("*** devEval() - initally and finally ... DONE")
+
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Try several devices until first successful device is found
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** devEval() - first successful device ...")
+
 types <- list(
   "png|jpg|pdf",               # PNG, JPG and then PDF
   "dummy|png|jpg|pdf",         # "Non-existing", PNG, JPG and then PDF
@@ -65,6 +78,11 @@ types <- list(
   "png,jpg|x11|windows"        # == c("png", "jpg|x11|windows")
 )
 
+if (!capabilitiesX11()) {
+  message("Skipping test for X11")
+  types <- lapply(types, FUN=function(x) gsub("x11|", "", x, fixed=TRUE))
+}
+
 devList0 <- devList()
 
 for (type in types) {
@@ -86,10 +104,14 @@ for (type in types) {
 # Sanity check
 stopifnot(all.equal(devList(), devList0))
 
+message("*** devEval() - first successful device ... DONE")
+
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Plot a parsed expression
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** devEval() - parsed expressions ...")
+
 expr <- substitute(plot(1:10))
 tryCatch({
   res <- devEval("png|jpg", name="any", width=480L, height=480L, {
@@ -102,10 +124,14 @@ tryCatch({
   printf("Failed: %s\n\n", sQuote(ex$message))
 })
 
+message("*** devEval() - parsed expressions ... DONE")
+
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Special cases
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** toDefault(<expr>) ...")
+
 # toX11({ plot(1:10) }) actually results in a call to
 # devEval(type="x11", name={ plot(1:10) }); note argument 'name'
 # and not 'expr'.  The following tests that devEval() recognizes
@@ -122,10 +148,15 @@ if (interactive()) {
 }
 
 
+message("*** toDefault(<expr>) ... DONE")
+
+
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Device type specified as a device functions
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** devEval(<fcn>) ...")
+
 types <- list(
   png=grDevices::png,
   jpg=grDevices::jpeg
@@ -144,10 +175,14 @@ for (name in names(types)) {
   stopifnot(all.equal(devList(), devList0))
 }
 
+message("*** devEval(<fcn>) ... DONE")
+
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Special case: Default device
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** devEval(<default>) ...")
+
 cat("Device types: 'default'\n")
 type <- getOption("device")
 str(type)
@@ -159,8 +194,12 @@ print(res)
 wasInteractiveOpened <- (length(setdiff(devList(), devList0)) > 0L)
 if (wasInteractiveOpened) devOff()
 
+message("*** devEval(<default>) ... DONE")
+
 
 
 # Sanity checks
 print(devList())
 stopifnot(length(devList()) == 0L)
+
+message("*** devEval() ... DONE")
